Skip to main contentModule bytes
Source - Bytes
- A cheaply cloneable and sliceable chunk of contiguous memory.
- BytesMut
- A unique reference to a contiguous slice of memory.
- Buf
- Read bytes from a buffer.
- BufMut
- A trait for values that provide sequential write access to bytes.